/****************************************************************************
** Meta object code from reading C++ file 'k3bdataviewimpl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.04.0/src/projects/k3bdataviewimpl.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bdataviewimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b12DataViewImplE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::DataViewImpl::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b12DataViewImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::DataViewImpl",
        "setCurrentRoot",
        "",
        "QModelIndex",
        "index",
        "slotCurrentRootChanged",
        "newRoot",
        "slotNewDir",
        "slotRemove",
        "slotRename",
        "slotProperties",
        "slotOpen",
        "slotSelectionChanged",
        "slotItemActivated",
        "slotEnterPressed",
        "slotImportSession",
        "slotClearImportedSession",
        "slotEditBootImages",
        "slotImportedSessionChanged",
        "importedSession",
        "slotAddUrlsRequested",
        "QList<QUrl>",
        "urls",
        "K3b::DirItem*",
        "targetDir",
        "slotMoveItemsRequested",
        "QList<K3b::DataItem*>",
        "items"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setCurrentRoot'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotCurrentRootChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 },
        }}),
        // Slot 'slotNewDir'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemove'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotProperties'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpen'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemActivated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotEnterPressed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportSession'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearImportedSession'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditBootImages'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportedSessionChanged'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'slotAddUrlsRequested'
        QtMocHelpers::SlotData<void(QList<QUrl>, K3b::DirItem *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotMoveItemsRequested'
        QtMocHelpers::SlotData<void(QList<K3b::DataItem*>, K3b::DirItem *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataViewImpl, qt_meta_tag_ZN3K3b12DataViewImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::DataViewImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b12DataViewImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b12DataViewImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b12DataViewImplE_t>.metaTypes,
    nullptr
} };

void K3b::DataViewImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataViewImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setCurrentRoot((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->slotCurrentRootChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->slotNewDir(); break;
        case 3: _t->slotRemove(); break;
        case 4: _t->slotRename(); break;
        case 5: _t->slotProperties(); break;
        case 6: _t->slotOpen(); break;
        case 7: _t->slotSelectionChanged(); break;
        case 8: _t->slotItemActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->slotEnterPressed(); break;
        case 10: _t->slotImportSession(); break;
        case 11: _t->slotClearImportedSession(); break;
        case 12: _t->slotEditBootImages(); break;
        case 13: _t->slotImportedSessionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->slotAddUrlsRequested((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<K3b::DirItem*>>(_a[2]))); break;
        case 15: _t->slotMoveItemsRequested((*reinterpret_cast<std::add_pointer_t<QList<K3b::DataItem*>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<K3b::DirItem*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataViewImpl::*)(const QModelIndex & )>(_a, &DataViewImpl::setCurrentRoot, 0))
            return;
    }
}

const QMetaObject *K3b::DataViewImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::DataViewImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b12DataViewImplE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int K3b::DataViewImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void K3b::DataViewImpl::setCurrentRoot(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
