/****************************************************************************
** Meta object code from reading C++ file 'k3bdevicehandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.04.0/libk3b/tools/k3bdevicehandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bdevicehandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::Device::DeviceHandler::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::Device::DeviceHandler",
        "finished",
        "",
        "K3b::Device::DeviceHandler*",
        "setDevice",
        "K3b::Device::Device*",
        "sendCommand",
        "Commands",
        "command",
        "getToc",
        "getDiskInfo",
        "getDiskSize",
        "getRemainingSize",
        "getTocType",
        "getNumSessions",
        "block",
        "eject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(K3b::Device::DeviceHandler *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(K3b::Device::Device *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'sendCommand'
        QtMocHelpers::SlotData<void(Commands)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'getToc'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getDiskInfo'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getDiskSize'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getRemainingSize'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getTocType'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getNumSessions'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'block'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'eject'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeviceHandler, qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::Device::DeviceHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<ThreadJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>.metaTypes,
    nullptr
} };

void K3b::Device::DeviceHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<K3b::Device::DeviceHandler*>>(_a[1]))); break;
        case 1: _t->setDevice((*reinterpret_cast<std::add_pointer_t<K3b::Device::Device*>>(_a[1]))); break;
        case 2: _t->sendCommand((*reinterpret_cast<std::add_pointer_t<Commands>>(_a[1]))); break;
        case 3: _t->getToc(); break;
        case 4: _t->getDiskInfo(); break;
        case 5: _t->getDiskSize(); break;
        case 6: _t->getRemainingSize(); break;
        case 7: _t->getTocType(); break;
        case 8: _t->getNumSessions(); break;
        case 9: _t->block((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->eject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< K3b::Device::DeviceHandler* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceHandler::*)(K3b::Device::DeviceHandler * )>(_a, &DeviceHandler::finished, 0))
            return;
    }
}

const QMetaObject *K3b::Device::DeviceHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::Device::DeviceHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b6Device13DeviceHandlerE_t>.strings))
        return static_cast<void*>(this);
    return ThreadJob::qt_metacast(_clname);
}

int K3b::Device::DeviceHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ThreadJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void K3b::Device::DeviceHandler::finished(K3b::Device::DeviceHandler * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
